@@ -82,13 +82,9 @@ class SkyPointSource(SkySpatialModel):
 
     @property
     def evaluation_radius(self):
-        """Returns the effective radius of the sky region where the model evaluates to non-zero.
-        For a Gaussian source, we fix it to :math:`0`.
+        """Evaluation radius (`~astropy.coordinates.Angle`).
 
-        Returns
-        -------
-        radius : `~astropy.units.Quantity`
-            Radius
+        Set as zero degrees.
         """
         return 0 * u.deg
 
@@ -159,13 +155,9 @@ class SkyGaussian(SkySpatialModel):
 
     @property
     def evaluation_radius(self):
-        r"""Returns the effective radius of the sky region where the model evaluates to non-zero.
-        For a Gaussian source, we fix it to :math:`5\sigma`.
+        r"""Evaluation radius (`~astropy.coordinates.Angle`).
 
-        Returns
-        -------
-        radius : `~astropy.coordinates.Angle`
-           Radius in angular units
+        Set as :math:`5\sigma`.
         """
         return 5 * self.parameters["sigma"].quantity
 
@@ -259,13 +251,9 @@ class SkyDisk(SkySpatialModel):
 
     @property
     def evaluation_radius(self):
-        r"""Returns the effective radius of the sky region where the model evaluates to non-zero.
-        For a Disk source, we fix it to :math:`r_0`.
+        r"""Evaluation radius (`~astropy.coordinates.Angle`).
 
-        Returns
-        -------
-        radius : `~astropy.coordinates.Angle`
-            Radius in angular units
+        Set to :math:`r_0`.
         """
         return self.parameters["r_0"].quantity
 
@@ -314,8 +302,8 @@ class SkyEllipse(SkySpatialModel):
         Eccentricity of the ellipse (:math:`0< e< 1`).
     theta : `~astropy.coordinates.Angle`
         :math:`\theta`:
-        Rotation angle of the major semiaxis.  The rotation angle increases clockwise
-        (i.e., East of North) from the positive `lon` axis.
+        Rotation angle of the major semiaxis.  The rotation angle increases counter-clockwise
+        from the North direction.
     edge : `~astropy.coordinates.Angle`
         Width of the edge. The width is defined as the range within the
         smooth edges of the model drops from 95% to 5% of its amplitude
@@ -334,7 +322,7 @@ class SkyEllipse(SkySpatialModel):
         from gammapy.image.models.core import SkyEllipse
         from gammapy.maps import Map, WcsGeom
 
-        model = SkyEllipse("2 deg", "2 deg", "1 deg", 0.8, "30 deg")
+        model = SkyEllipse("2 deg", "2 deg", "1 deg", 0.8, "30 deg", frame= "galactic")
 
         m_geom = WcsGeom.create(binsz=0.01, width=(3, 3), skydir=(2, 2), coordsys="GAL", proj="AIT")
         coords = m_geom.get_coord()
@@ -344,15 +332,16 @@ class SkyEllipse(SkySpatialModel):
         skymap = Map.from_geom(m_geom, data=vals.value)
 
         _, ax, _ = skymap.smooth("0.05 deg").plot()
+
         transform = ax.get_transform('galactic')
         ax.scatter(2, 2, transform=transform, s=20, edgecolor='red', facecolor='red')
-        ax.text(2.0, 1.8, r"$(l_0, b_0)$", transform=transform, ha="center")
-        ax.plot([2, 2 + np.cos(np.pi / 6)], [2, 2 + np.sin(np.pi / 6)], color="r", transform=transform)
-        ax.hlines(y=2, color='r', linestyle='--', transform=transform, xmin=0, xmax=5)
-        ax.text(2.5, 2.06, r"$\theta$", transform=transform);
+        ax.text(1.7, 1.85, r"$(l_0, b_0)$", transform=transform, ha="center")
+        ax.plot([2, 2 + np.sin(np.pi / 6)], [2, 2 + np.cos(np.pi / 6)], color="r", transform=transform)
+        ax.vlines(x=2, color='r', linestyle='--', transform=transform, ymin=0, ymax=5)
+        ax.text(2.15, 2.3, r"$\theta$", transform=transform);
 
         plt.show()
-    """
+        """
 
     __slots__ = ["frame", "lon_0", "lat_0", "semi_major", "e", "theta", "_offset_by"]
 
@@ -382,17 +371,11 @@ class SkyEllipse(SkySpatialModel):
 
     @property
     def evaluation_radius(self):
-        r"""Returns the effective radius of the sky region where the model evaluates to non-zero.
-        For an elliptical source, we fix it to the length of the semi-major axis.
-
-        Returns
-        -------
-        radius : `~astropy.coordinates.Angle`
-            Radius in angular units
+        """Evaluation radius (`~astropy.coordinates.Angle`).
 
+        Set to the length of the semi-major axis.
         """
-        radius = self.parameters["semi_major"].quantity
-        return radius
+        return self.parameters["semi_major"].quantity
 
     @staticmethod
     def compute_norm(semi_major, e):
@@ -415,8 +398,8 @@ class SkyEllipse(SkySpatialModel):
         """Evaluate the model (static function)."""
         # find the foci of the ellipse
         c = semi_major * e
-        lon_1, lat_1 = self._offset_by(lon_0, lat_0, 90 * u.deg - theta, c)
-        lon_2, lat_2 = self._offset_by(lon_0, lat_0, 270 * u.deg - theta, c)
+        lon_1, lat_1 = self._offset_by(lon_0, lat_0, theta, c)
+        lon_2, lat_2 = self._offset_by(lon_0, lat_0, 180 * u.deg + theta, c)
 
         sep_1 = angular_separation(lon, lat, lon_1, lat_1)
         sep_2 = angular_separation(lon, lat, lon_2, lat_2)
@@ -474,14 +457,9 @@ class SkyShell(SkySpatialModel):
 
     @property
     def evaluation_radius(self):
-        r"""Returns the effective radius of the sky region where the model evaluates to non-zero.
+        r"""Evaluation radius (`~astropy.coordinates.Angle`).
 
-        Given by :math:`r_\text{out}`.
-
-        Returns
-        -------
-        radius : `~astropy.coordinates.Angle`
-            Radius in angular units
+        Set to :math:`r_\text{out}`.
         """
         return self.parameters["radius"].quantity + self.parameters["width"].quantity
 
@@ -524,13 +502,9 @@ class SkyDiffuseConstant(SkySpatialModel):
 
     @property
     def evaluation_radius(self):
-        r"""Returns the effective radius of the sky region where the model evaluates to non-zero.
-        For a constant diffuse model, we fix it to None.
+        """Evaluation radius (``None``).
 
-        Returns
-        -------
-        radius : `~astropy.coordinates.Angle`
-             None
+        Set to ``None``.
         """
         return None
 
@@ -560,9 +534,11 @@ class SkyDiffuseMap(SkySpatialModel):
         Default arguments are {'interp': 'linear', 'fill_value': 0}.
     """
 
-    __slots__ = ["map", "norm", "meta", "_interp_kwargs"]
+    __slots__ = ["map", "norm", "meta", "_interp_kwargs", "filename"]
 
-    def __init__(self, map, norm=1, meta=None, normalize=True, interp_kwargs=None):
+    def __init__(
+        self, map, norm=1, meta=None, normalize=True, interp_kwargs=None, filename=None
+    ):
         if (map.data < 0).any():
             log.warning("Diffuse map has negative values. Check and fix this!")
 
@@ -578,18 +554,14 @@ class SkyDiffuseMap(SkySpatialModel):
         interp_kwargs.setdefault("interp", "linear")
         interp_kwargs.setdefault("fill_value", 0)
         self._interp_kwargs = interp_kwargs
-
+        self.filename = filename
         super().__init__([self.norm])
 
     @property
     def evaluation_radius(self):
-        r"""Returns the effective radius of the sky region where the model evaluates to non-zero.
-        For a DiffuseMap source, we fix it to half of the maximal dimension of the map.
+        """Evaluation radius (`~astropy.coordinates.Angle`).
 
-        Returns
-        -------
-        radius : `~astropy.coordinates.Angle`
-            Radius in angular units.
+        Set to half of the maximal dimension of the map.
         """
         return np.max(self.map.geom.width) / 2.0
 
@@ -617,7 +589,7 @@ class SkyDiffuseMap(SkySpatialModel):
         m = Map.read(filename, **kwargs)
         if m.unit == "":
             m.unit = "sr-1"
-        return cls(m, normalize=normalize)
+        return cls(m, normalize=normalize, filename=filename)
 
     def evaluate(self, lon, lat, norm):
         """Evaluate model."""
